@@ -30,6 +30,6 @@ pub trait Context:
 }
 
 #[async_trait]
-pub trait ContextProvider<T: Context> {
-    async fn new_context(&self) -> Result<T, Error>;
+pub trait ContextProvider<'a, T: Context> {
+    async fn new_context(&'a self) -> Result<T, Error>;
 }
