@@ -29,7 +29,7 @@ pub struct AddOrRemoveItemParams {
 }
 
 #[async_trait]
-pub trait Server<T: Context>: ContextProvider<T> {
+pub trait Server<'a, T: Context>: ContextProvider<'a, T> {
     type Context: ServerContext;
     fn api_description() -> ApiDescription<Self::Context>;
     async fn start(self) -> Result<(), Error>;
